@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,9 +7,7 @@
 #include "editorutil.h"
 
 using namespace KPIMTextEdit;
-EditorUtil::EditorUtil()
-{
-}
+EditorUtil::EditorUtil() = default;
 
 void EditorUtil::upperCase(QTextCursor &cursor) const
 {
