@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,7 +7,6 @@
 #include "texteditfindbarbase.h"
 #include "kpimtextedit_debug.h"
 #include "texteditor/commonwidget/textfindreplacewidget.h"
-#include <KColorScheme>
 #include <KLocalizedString>
 #include <QEvent>
 #include <QHBoxLayout>
@@ -22,6 +21,8 @@ using namespace KPIMTextEdit;
 
 TextEditFindBarBase::TextEditFindBarBase(QWidget *parent)
     : QWidget(parent)
+    , mFindWidget(new TextFindWidget(this))
+    , mReplaceWidget(new TextReplaceWidget(this))
 {
     auto topLayout = new QVBoxLayout(this);
     auto lay = new QHBoxLayout;
@@ -39,10 +40,8 @@ TextEditFindBarBase::TextEditFindBarBase(QWidget *parent)
     closeBtn->setAutoRaise(true);
     lay->addWidget(closeBtn);
 
-    mFindWidget = new TextFindWidget(this);
     lay->addWidget(mFindWidget);
 
-    mReplaceWidget = new TextReplaceWidget(this);
     topLayout->addWidget(mReplaceWidget);
     mReplaceWidget->hide();
 
@@ -59,9 +58,7 @@ TextEditFindBarBase::TextEditFindBarBase(QWidget *parent)
     hide();
 }
 
-TextEditFindBarBase::~TextEditFindBarBase()
-{
-}
+TextEditFindBarBase::~TextEditFindBarBase() = default;
 
 void TextEditFindBarBase::showFind()
 {
@@ -147,10 +144,10 @@ void TextEditFindBarBase::messageInfo(bool backward, bool isAutoSearch, bool fou
 bool TextEditFindBarBase::searchText(bool backward, bool isAutoSearch)
 {
     mLastSearchStr = mFindWidget->searchText();
-    mLastSearchRegExp = mFindWidget->searchRegExp();
-    QTextDocument::FindFlags searchOptions = mFindWidget->searchOptions();
+    mLastSearchRegExp = mFindWidget->searchRegularExpression();
+    TextEditFindBarBase::FindFlags searchOptions = mFindWidget->searchOptions();
     if (backward) {
-        searchOptions |= QTextDocument::FindBackward;
+        searchOptions |= TextEditFindBarBase::FindBackward;
     }
 
     if (isAutoSearch) {
@@ -184,9 +181,9 @@ void TextEditFindBarBase::findPrev()
 
 void TextEditFindBarBase::slotUpdateSearchOptions()
 {
-    const QTextDocument::FindFlags searchOptions = mFindWidget->searchOptions();
+    const TextEditFindBarBase::FindFlags searchOptions = mFindWidget->searchOptions();
     mLastSearchStr = mFindWidget->searchText();
-    mLastSearchRegExp = mFindWidget->searchRegExp();
+    mLastSearchRegExp = mFindWidget->searchRegularExpression();
     if (mFindWidget->isRegularExpression()) {
         searchInDocument(mLastSearchRegExp, searchOptions);
     } else {
